@@ -14,7 +14,7 @@ from ..enums import (
     Driver,
     PostgreSQLSSLMode,
     MySQLCharset,
-    MongoDBReadPreference,
+    MongoReadPreference,
     ElasticsearchScheme,
 )
 
@@ -41,7 +41,7 @@ class BaseConnectionConfig(
 
     # Optional fields for different database types
     auth_source: OptionalString = Field(
-        None, description="Authentication database (MongoDB)"
+        None, description="Authentication database (Mongo)"
     )
     ssl: OptionalBoolean = Field(None, description="Enable SSL connection")
     options: OptionalStringToAnyDict = Field(
@@ -70,7 +70,7 @@ class BaseConnectionConfig(
                 raise ValueError("Redis requires host")
         elif self.driver is Driver.MONGODB:
             if not self.host:
-                raise ValueError("MongoDB requires host")
+                raise ValueError("Mongo requires host")
 
         return self
 
@@ -141,7 +141,7 @@ class BaseConnectionConfig(
         raise NotImplementedError()
 
     def _make_mongodb_url(self) -> str:
-        """MongoDB URL format - MongoDB driver handles async/sync internally."""
+        """Mongo URL format - Mongo driver handles async/sync internally."""
         raise NotImplementedError()
 
     def _make_redis_url(self) -> str:
@@ -307,7 +307,6 @@ class PostgreSQLConnectionConfig(
 
         # Add PostgreSQL-specific options
         pg_options = {
-            "echo": self.echo,
             "sslmode": self.sslmode,
             "application_name": self.application_name,
         }
@@ -409,21 +408,21 @@ class SQLServerConnectionConfig(
         return self.model_dump(include={"echo"}, exclude_none=True)
 
 
-class MongoDBConnectionConfig(
+class MongoConnectionConfig(
     BaseConnectionConfig[
         Literal[Driver.MONGODB], OptionalString, OptionalString, str, int, str
     ]
 ):
     driver: Literal[Driver.MONGODB] = Driver.MONGODB
-    port: int = Field(27017, description="MongoDB port")
-    username: OptionalString = Field(None, description="MongoDB username")
-    password: OptionalString = Field(None, description="MongoDB password")
+    port: int = Field(27017, description="Mongo port")
+    username: OptionalString = Field(None, description="Mongo username")
+    password: OptionalString = Field(None, description="Mongo password")
 
-    # MongoDB-specific options
+    # Mongo-specific options
     auth_source: OptionalString = Field("admin", description="Authentication database")
     replica_set: OptionalString = Field(None, description="Replica set name")
-    read_preference: Optional[MongoDBReadPreference] = Field(
-        MongoDBReadPreference.PRIMARY, description="Read preference"
+    read_preference: Optional[MongoReadPreference] = Field(
+        MongoReadPreference.PRIMARY, description="Read preference"
     )
 
     @model_validator(mode="after")
@@ -436,8 +435,8 @@ class MongoDBConnectionConfig(
         return self
 
     def _make_mongodb_url(self) -> str:
-        """MongoDB URL format - MongoDB driver handles async/sync internally."""
-        # MongoDB uses the same URL format for both async and sync
+        """Mongo URL format - Mongo driver handles async/sync internally."""
+        # Mongo uses the same URL format for both async and sync
         # The async/sync behavior is determined by the client library used
 
         auth_part = ""
@@ -448,7 +447,7 @@ class MongoDBConnectionConfig(
 
         base_url = f"mongodb://{auth_part}{self.host}:{self.port}/{self.database}"
 
-        # Add MongoDB-specific options
+        # Add Mongo-specific options
         mongo_options = {
             "authSource": self.auth_source,
             "replicaSet": self.replica_set,
@@ -547,7 +546,7 @@ def create_connection_config(driver: Driver, **kwargs) -> BaseConnectionConfig:
         Driver.POSTGRESQL: PostgreSQLConnectionConfig,
         Driver.MYSQL: MySQLConnectionConfig,
         Driver.SQLITE: SQLiteConnectionConfig,
-        Driver.MONGODB: MongoDBConnectionConfig,
+        Driver.MONGODB: MongoConnectionConfig,
         Driver.REDIS: RedisConnectionConfig,
         Driver.MSSQL: SQLServerConnectionConfig,
         Driver.ELASTICSEARCH: ElasticsearchConnectionConfig,
