@@ -258,8 +258,8 @@ class ElasticsearchPoolingConfig(BasePoolingConfig):
         return self.model_dump(exclude=self.client_kwargs_exclusions, exclude_none=True)
 
 
-class MongoDBPoolingConfig(BasePoolingConfig):
-    """MongoDB-specific pooling configuration."""
+class MongoPoolingConfig(BasePoolingConfig):
+    """Mongo-specific pooling configuration."""
 
     model_config = ConfigDict(alias_generator=to_camel)
 
@@ -336,7 +336,7 @@ class RedisPoolingConfig(BasePoolingConfig):
 
     @property
     def client_kwargs_exclusions(self) -> Set[str]:
-        return {"health_check_interval"}
+        return {"health_check_interval", "connection_timeout"}
 
     @property
     def client_kwargs(self) -> StringToAnyDict:
