@@ -6,8 +6,8 @@ from motor.motor_asyncio import AsyncIOMotorClient
 from pymongo import MongoClient
 from redis.asyncio import Redis as AsyncRedis
 from redis import Redis as SyncRedis
-from sqlalchemy import MetaData, text
-from typing import Generic, Optional, TypeVar
+from sqlalchemy import text
+from typing import Generic, Optional, Type, TypeVar
 from uuid import uuid4
 from maleo.dtos.authentication import GenericAuthentication
 from maleo.dtos.contexts.operation import generate_operation_context
@@ -37,12 +37,13 @@ from ..config import (
     SQLServerConfig,
     SQLConfigT,
     ElasticsearchConfig,
-    MongoDBConfig,
+    MongoConfig,
     RedisConfig,
     NoSQLConfigT,
     ConfigT,
 )
 from ..enums import Connection
+from ..types import DeclarativeBaseT
 from .client import (
     AsyncClientT,
     SyncClientT,
@@ -52,7 +53,7 @@ from .engine import EngineManager
 from .session import SessionManager
 
 
-class DatabaseManager(ABC, Generic[ConfigT]):
+class Manager(ABC, Generic[ConfigT]):
     def __init__(
         self,
         config: ConfigT,
@@ -96,16 +97,15 @@ class DatabaseManager(ABC, Generic[ConfigT]):
         pass
 
 
-class SQLDatabaseManager(DatabaseManager[SQLConfigT], Generic[SQLConfigT]):
+class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
     def __init__(
         self,
+        Base: Type[DeclarativeBaseT],
         config: SQLConfigT,
-        metadata: MetaData,
         logger: Database,
         service_context: Optional[ServiceContext] = None,
     ) -> None:
         super().__init__(config, logger, service_context)
-        self._metadata = metadata
         self._operation_context.target.details = self._config.model_dump()
         self._engine_manager = EngineManager[SQLConfigT](config)
         self._session_manager = SessionManager(
@@ -114,7 +114,8 @@ class SQLDatabaseManager(DatabaseManager[SQLConfigT], Generic[SQLConfigT]):
             logger=self._logger,
             service_context=self._service_context,
         )
-        self._metadata.create_all(bind=self._engine_manager.get(Connection.SYNC))
+        self.Base = Base
+        self.Base.metadata.create_all(bind=self._engine_manager.get(Connection.SYNC))
 
     @property
     def engine(self) -> EngineManager[SQLConfigT]:
@@ -124,7 +125,7 @@ class SQLDatabaseManager(DatabaseManager[SQLConfigT], Generic[SQLConfigT]):
     def session(self) -> SessionManager:
         return self._session_manager
 
-    async def async_check_connnection(
+    async def async_check_connection(
         self,
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
@@ -251,33 +252,41 @@ class SQLDatabaseManager(DatabaseManager[SQLConfigT], Generic[SQLConfigT]):
         await self._engine_manager.dispose()
 
 
-class MySQLDatabaseManager(SQLDatabaseManager[MySQLConfig]):
+class MySQLManager(
+    SQLManager[MySQLConfig, DeclarativeBaseT], Generic[DeclarativeBaseT]
+):
     pass
 
 
-class PostgreSQLDatabaseManager(SQLDatabaseManager[PostgreSQLConfig]):
+class PostgreSQLManager(
+    SQLManager[PostgreSQLConfig, DeclarativeBaseT], Generic[DeclarativeBaseT]
+):
     pass
 
 
-class SQLiteDatabaseManager(SQLDatabaseManager[SQLiteConfig]):
+class SQLiteManager(
+    SQLManager[SQLiteConfig, DeclarativeBaseT], Generic[DeclarativeBaseT]
+):
     pass
 
 
-class SQLServerDatabaseManager(SQLDatabaseManager[SQLServerConfig]):
+class SQLServerManager(
+    SQLManager[SQLServerConfig, DeclarativeBaseT], Generic[DeclarativeBaseT]
+):
     pass
 
 
-SQLDatabaseManagerT = TypeVar(
-    "SQLDatabaseManagerT",
-    MySQLDatabaseManager,
-    PostgreSQLDatabaseManager,
-    SQLiteDatabaseManager,
-    SQLServerDatabaseManager,
+SQLManagerT = TypeVar(
+    "SQLManagerT",
+    MySQLManager,
+    PostgreSQLManager,
+    SQLiteManager,
+    SQLServerManager,
 )
 
 
-class NoSQLDatabaseManager(
-    DatabaseManager[NoSQLConfigT],
+class NoSQLManager(
+    Manager[NoSQLConfigT],
     Generic[
         NoSQLConfigT,
         AsyncClientT,
@@ -287,12 +296,10 @@ class NoSQLDatabaseManager(
     def __init__(
         self,
         config: NoSQLConfigT,
-        metadata: MetaData,
         logger: Database,
         service_context: Optional[ServiceContext] = None,
     ) -> None:
         super().__init__(config, logger, service_context)
-        self._metadata = metadata
         self._operation_context.target.details = self._config.model_dump()
         self._client_manager = ClientManager[
             NoSQLConfigT,
@@ -308,7 +315,7 @@ class NoSQLDatabaseManager(
     ]:
         return self._client_manager
 
-    async def async_check_connnection(
+    async def async_check_connection(
         self,
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
@@ -360,42 +367,35 @@ class NoSQLDatabaseManager(
         await self._client_manager.dispose()
 
 
-class ElasticsearchDatabaseManager(
-    NoSQLDatabaseManager[ElasticsearchConfig, AsyncElasticsearch, Elasticsearch]
+class ElasticsearchManager(
+    NoSQLManager[ElasticsearchConfig, AsyncElasticsearch, Elasticsearch]
 ):
     pass
 
 
-class MongoDBDatabaseManager(
-    NoSQLDatabaseManager[MongoDBConfig, AsyncIOMotorClient, MongoClient]
-):
+class MongoManager(NoSQLManager[MongoConfig, AsyncIOMotorClient, MongoClient]):
     pass
 
 
-class RedisDatabaseManager(NoSQLDatabaseManager[RedisConfig, AsyncRedis, SyncRedis]):
+class RedisManager(NoSQLManager[RedisConfig, AsyncRedis, SyncRedis]):
     pass
 
 
-NoSQLDatabaseManagerT = TypeVar(
-    "NoSQLDatabaseManagerT",
-    ElasticsearchDatabaseManager,
-    MongoDBDatabaseManager,
-    RedisDatabaseManager,
+NoSQLManagerT = TypeVar(
+    "NoSQLManagerT",
+    ElasticsearchManager,
+    MongoManager,
+    RedisManager,
 )
 
 
-GenericDatabaseManagerT = TypeVar(
-    "GenericDatabaseManagerT", SQLDatabaseManager, NoSQLDatabaseManager
-)
-
-
-SpecificDatabaseManagerT = TypeVar(
-    "SpecificDatabaseManagerT",
-    MySQLDatabaseManager,
-    PostgreSQLDatabaseManager,
-    SQLiteDatabaseManager,
-    SQLServerDatabaseManager,
-    ElasticsearchDatabaseManager,
-    MongoDBDatabaseManager,
-    RedisDatabaseManager,
+ManagerT = TypeVar(
+    "ManagerT",
+    ElasticsearchManager,
+    MongoManager,
+    RedisManager,
+    MySQLManager,
+    PostgreSQLManager,
+    SQLiteManager,
+    SQLServerManager,
 )
