@@ -7,7 +7,7 @@ from typing import Generic, Literal, Optional, Tuple, TypeVar, Union, overload
 from maleo.types.base.string import ListOfStrings
 from ..config import (
     ElasticsearchConfig,
-    MongoDBConfig,
+    MongoConfig,
     RedisConfig,
     NoSQLConfigT,
 )
@@ -65,9 +65,7 @@ class ElasticsearchClientManager(
     pass
 
 
-class MongoDBClientManager(
-    ClientManager[MongoDBConfig, AsyncIOMotorClient, MongoClient]
-):
+class MongoClientManager(ClientManager[MongoConfig, AsyncIOMotorClient, MongoClient]):
     pass
 
 
@@ -98,6 +96,6 @@ class RedisClientManager(ClientManager[RedisConfig, AsyncRedis, SyncRedis]):
 ClientManagerT = TypeVar(
     "ClientManagerT",
     ElasticsearchClientManager,
-    MongoDBClientManager,
+    MongoClientManager,
     RedisClientManager,
 )
