@@ -92,7 +92,7 @@ class SessionManager(Generic[SQLConfigT]):
         operation_action = SystemOperationAction(
             type=SystemOperationType.DATABASE_CONNECTION, details=None
         )
-        session = self._async_sessionmaker()
+        session: AsyncSession = self._async_sessionmaker()
         SuccessfulSystemOperation[
             Optional[GenericAuthentication], NoDataResponse[None]
         ](
@@ -111,8 +111,9 @@ class SessionManager(Generic[SQLConfigT]):
 
         executed_at = datetime.now(tz=timezone.utc)
         try:
-            yield session  # Provide session
-            await session.commit()  # Auto-commit on success
+            # explicit transaction context — will commit on success, rollback on exception
+            async with session.begin():
+                yield session
             SuccessfulSystemOperation[
                 Optional[GenericAuthentication], NoDataResponse[None]
             ](
@@ -129,7 +130,11 @@ class SessionManager(Generic[SQLConfigT]):
                 self._logger, level=Level.INFO
             )
         except SQLAlchemyError as se:
-            await session.rollback()  # Rollback on error
+            # session.begin() will rollback, but keep explicit rollback to be safe
+            try:
+                await session.rollback()
+            except Exception:
+                pass
             error = DatabaseError[Optional[GenericAuthentication]](
                 OperationType.SYSTEM,
                 service_context=self._service_context,
@@ -152,7 +157,10 @@ class SessionManager(Generic[SQLConfigT]):
             operation.log(self._logger, level=Level.ERROR)
             raise error from se
         except ValidationError as ve:
-            await session.rollback()  # Rollback on error
+            try:
+                await session.rollback()
+            except Exception:
+                pass
             error = UnprocessableEntity[Optional[GenericAuthentication]](
                 OperationType.SYSTEM,
                 service_context=self._service_context,
@@ -169,9 +177,16 @@ class SessionManager(Generic[SQLConfigT]):
             operation.log(self._logger, level=Level.ERROR)
             raise error from ve
         except MaleoException:
+            try:
+                await session.rollback()
+            except Exception:
+                pass
             raise
         except Exception as e:
-            await session.rollback()  # Rollback on error
+            try:
+                await session.rollback()
+            except Exception:
+                pass
             error = InternalServerError[Optional[GenericAuthentication]](
                 OperationType.SYSTEM,
                 service_context=self._service_context,
@@ -194,7 +209,11 @@ class SessionManager(Generic[SQLConfigT]):
             operation.log(self._logger, level=Level.ERROR)
             raise error from e
         finally:
-            await session.close()  # Ensure session closes
+            # close session
+            try:
+                await session.close()
+            except Exception:
+                pass
             SuccessfulSystemOperation[
                 Optional[GenericAuthentication], NoDataResponse[None]
             ](
@@ -222,7 +241,7 @@ class SessionManager(Generic[SQLConfigT]):
         operation_action = SystemOperationAction(
             type=SystemOperationType.DATABASE_CONNECTION, details=None
         )
-        session = self._sync_sessionmaker()
+        session: Session = self._sync_sessionmaker()
         SuccessfulSystemOperation[
             Optional[GenericAuthentication], NoDataResponse[None]
         ](
@@ -241,8 +260,9 @@ class SessionManager(Generic[SQLConfigT]):
 
         executed_at = datetime.now(tz=timezone.utc)
         try:
-            yield session  # Provide session
-            session.commit()  # Auto-commit on success
+            # explicit transaction context — will commit on success, rollback on exception
+            with session.begin():
+                yield session
             SuccessfulSystemOperation[
                 Optional[GenericAuthentication], NoDataResponse[None]
             ](
